/**
 * External dependencies
 */
import { decodeEntities } from '@wordpress/html-entities';
import { __ } from '@wordpress/i18n';
import { registerPaymentMethod } from '@woocommerce/blocks-registry';

/**
 * Internal dependencies
 */
import { PAYMENT_METHOD_NAME } from './constants';
import { getGoCardlessServerData } from './gocardless-utils';

const { description, logo_url: logoUrl, title } = getGoCardlessServerData();

const Content = () => {
	return decodeEntities(description || '');
};

const Logo = () => {
	return <img src={logoUrl} alt={decodeEntities(title)} />;
};

const Label = (props) => {
	const { PaymentMethodLabel } = props.components;
	return <PaymentMethodLabel text={decodeEntities(title)} icon={<Logo />} />;
};

registerPaymentMethod({
	name: PAYMENT_METHOD_NAME,
	label: <Label />,
	ariaLabel: __(
		'GoCardless payment method',
		'woocommerce-gateway-gocardless'
	),
	canMakePayment: ({ billingData }) => {
		// Check if the country is supported.
		const supportedCountries =
			getGoCardlessServerData()?.supportedCountries || [];
		return supportedCountries.includes(billingData?.country);
	},
	content: <Content />,
	edit: <Content />,
	supports: {
		// Use `false` as fallback values in case server provided configuration is missing.
		showSavedCards: getGoCardlessServerData().showSavedCards ?? false,
		showSaveOption: getGoCardlessServerData().showSaveOption ?? false,
		features: getGoCardlessServerData()?.supports ?? [],
	},
});
